/* Copyright (C) 2000-2002 Joakim Axelsson <gozem@linux.nu>
 *                         Patrick Schaaf <bof@bof.de>
 * Copyright (C) 2003-2007 Jozsef Kadlecsik <kadlec@blackhole.kfki.hu>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.  
 */

/* Kernel module implementing an IP set type: the single bitmap type */

#include <linux/module.h>
#include <linux/skbuff.h>
#include <linux/netfilter/nfnetlink.h>
#include <linux/netfilter/nf_set.h>

MODULE_LICENSE("GPL");
MODULE_AUTHOR("Jozsef Kadlecsik <kadlec@blackhole.kfki.hu>");
MODULE_DESCRIPTION("ipmap type of IP sets");

extern struct nf_set_type nf_set_type_ipmap_ipv4;
extern struct nf_set_type nf_set_type_ipmap_ipv6;

static int __init nf_set_init_ipmap(void)
{
	int ret;
	
	ret = nf_set_register_set_type(&nf_set_type_ipmap_ipv4);
#if defined(CONFIG_IPV6) || defined(CONFIG_IPV6_MODULE)
	if (!ret) {
		ret = nf_set_register_set_type(&nf_set_type_ipmap_ipv6);
		if (ret)
			nf_set_unregister_set_type(&nf_set_type_ipmap_ipv4);
	}
#endif
	return ret;
}

static void __exit nf_set_fini_ipmap(void)
{
	/* FIXME: possible race with nf_set_create() */
	nf_set_unregister_set_type(&nf_set_type_ipmap_ipv4);
#if defined(CONFIG_IPV6) || defined(CONFIG_IPV6_MODULE)
	nf_set_unregister_set_type(&nf_set_type_ipmap_ipv6);
#endif
}

module_init(nf_set_init_ipmap);
module_exit(nf_set_fini_ipmap);
